@@ -29,13 +29,13 @@ def inject_adsense_after_paragraph(value,params):
         for i, para in enumerate(paragraphs):
             if len(para)>450:
                 if ad_count < len(paragraphs)/10:
-                    paragraphs[i] = paragraphs[i] + ad_code + "<p></p>"
+                    paragraphs[i] = paragraphs[i] + "<p></p>" + ad_code + "<p></p>"
 
                     value = "</p>".join(paragraphs)
                     ad_count += 1
     else:
         if ad_after<len(paragraphs):
-            paragraphs[ad_after] = paragraphs[ad_after] + ad_code + "<p></p>"
+            paragraphs[ad_after] = paragraphs[ad_after] + "<p></p>" + ad_code + "<p></p>"
 
             value = "</p>".join(paragraphs)
 
